@@ -1,9 +1,21 @@
+import base64
 import uuid
-from typing import Callable, Collection, Dict, List, Optional, Set, TYPE_CHECKING, cast
+from typing import (
+    Any,
+    Callable,
+    Collection,
+    Dict,
+    List,
+    Optional,
+    Set,
+    TYPE_CHECKING,
+    cast,
+)
 
-import ormar
+import pydantic
+
+import ormar  # noqa: I100, I202
 from ormar.exceptions import ModelPersistenceError
-from ormar.models.helpers.validation import validate_choices
 from ormar.models.mixins import AliasMixin
 from ormar.models.mixins.relation_mixin import RelationMixin
 
@@ -19,6 +31,7 @@ class SavePrepareMixin(RelationMixin, AliasMixin):
     if TYPE_CHECKING:  # pragma: nocover
         _choices_fields: Optional[Set]
         _skip_ellipsis: Callable
+        __fields__: Dict[str, pydantic.fields.ModelField]
 
     @classmethod
     def prepare_model_to_save(cls, new_kwargs: dict) -> dict:
@@ -39,6 +52,7 @@ class SavePrepareMixin(RelationMixin, AliasMixin):
         new_kwargs = cls._remove_not_ormar_fields(new_kwargs)
         new_kwargs = cls.substitute_models_with_pks(new_kwargs)
         new_kwargs = cls.populate_default_values(new_kwargs)
+        new_kwargs = cls.reconvert_str_to_bytes(new_kwargs)
         new_kwargs = cls.translate_columns_to_aliases(new_kwargs)
         return new_kwargs
 
@@ -93,7 +107,7 @@ class SavePrepareMixin(RelationMixin, AliasMixin):
             if field.__type__ == uuid.UUID and name in model_dict:
                 parsers = {"string": lambda x: str(x), "hex": lambda x: "%.32x" % x.int}
                 uuid_format = field.column_type.uuid_format
-                parser = parsers.get(uuid_format, lambda x: x)
+                parser: Callable[..., Any] = parsers.get(uuid_format, lambda x: x)
                 model_dict[name] = parser(model_dict[name])
         return model_dict
 
@@ -132,6 +146,36 @@ class SavePrepareMixin(RelationMixin, AliasMixin):
                     model_dict.pop(field, None)
         return model_dict
 
+    @classmethod
+    def reconvert_str_to_bytes(cls, model_dict: Dict) -> Dict:
+        """
+        Receives dictionary of model that is about to be saved and changes
+        all bytes fields that are represented as strings back into bytes.
+
+        :param model_dict: dictionary of model that is about to be saved
+        :type model_dict: Dict
+        :return: dictionary of model that is about to be saved
+        :rtype: Dict
+        """
+        bytes_fields = {
+            name
+            for name, field in cls.Meta.model_fields.items()
+            if field.__type__ == bytes
+        }
+        bytes_base64_fields = {
+            name
+            for name, field in cls.Meta.model_fields.items()
+            if field.represent_as_base64_str
+        }
+        for key, value in model_dict.items():
+            if key in bytes_fields and isinstance(value, str):
+                model_dict[key] = (
+                    value.encode("utf-8")
+                    if key not in bytes_base64_fields
+                    else base64.b64decode(value)
+                )
+        return model_dict
+
     @classmethod
     def populate_default_values(cls, new_kwargs: Dict) -> Dict:
         """
@@ -152,7 +196,10 @@ class SavePrepareMixin(RelationMixin, AliasMixin):
             ):
                 new_kwargs[field_name] = field.get_default()
             # clear fields with server_default set as None
-            if field.server_default is not None and not new_kwargs.get(field_name):
+            if (
+                field.server_default is not None
+                and new_kwargs.get(field_name, None) is None
+            ):
                 new_kwargs.pop(field_name, None)
         return new_kwargs
 
@@ -170,9 +217,18 @@ class SavePrepareMixin(RelationMixin, AliasMixin):
         if not cls._choices_fields:
             return new_kwargs
 
-        for field_name, field in cls.Meta.model_fields.items():
-            if field_name in new_kwargs and field_name in cls._choices_fields:
-                validate_choices(field=field, value=new_kwargs.get(field_name))
+        fields_to_check = [
+            field
+            for field in cls.Meta.model_fields.values()
+            if field.name in cls._choices_fields and field.name in new_kwargs
+        ]
+        for field in fields_to_check:
+            if new_kwargs[field.name] not in field.choices:
+                raise ValueError(
+                    f"{field.name}: '{new_kwargs[field.name]}' "
+                    f"not in allowed choices set:"
+                    f" {field.choices}"
+                )
         return new_kwargs
 
     @staticmethod
@@ -222,7 +278,7 @@ class SavePrepareMixin(RelationMixin, AliasMixin):
 
     @staticmethod
     async def _upsert_through_model(
-        instance: "Model", previous_model: "Model", relation_field: "ForeignKeyField",
+        instance: "Model", previous_model: "Model", relation_field: "ForeignKeyField"
     ) -> None:
         """
         Upsert through model for m2m relation.
