@@ -57,7 +57,7 @@ class FilterAction(QueryAction):
     Extracted in order to easily change table prefixes on complex relations.
     """
 
-    def __init__(self, filter_str: str, value: Any, model_cls: Type["Model"],) -> None:
+    def __init__(self, filter_str: str, value: Any, model_cls: Type["Model"]) -> None:
         super().__init__(query_str=filter_str, model_cls=model_cls)
         self.filter_value = value
         self._escape_characters_in_clause()
@@ -148,7 +148,7 @@ class FilterAction(QueryAction):
             filter_value = self.filter_value
         clause = getattr(self.column, op_attr)(filter_value)
         clause = self._compile_clause(
-            clause, modifiers={"escape": "\\" if self.has_escaped_character else None},
+            clause, modifiers={"escape": "\\" if self.has_escaped_character else None}
         )
         return clause
 
@@ -170,7 +170,7 @@ class FilterAction(QueryAction):
             ]
 
     def _compile_clause(
-        self, clause: sqlalchemy.sql.expression.BinaryExpression, modifiers: Dict,
+        self, clause: sqlalchemy.sql.expression.BinaryExpression, modifiers: Dict
     ) -> sqlalchemy.sql.expression.TextClause:
         """
         Compiles the clause to str using appropriate database dialect, replace columns
