@@ -247,7 +247,7 @@ class QuerySet(Generic[T]):
         return self.model_meta.table
 
     def build_select_expression(
-        self, limit: int = None, offset: int = None, order_bys: List = None,
+        self, limit: int = None, offset: int = None, order_bys: List = None
     ) -> sqlalchemy.sql.select:
         """
         Constructs the actual database query used in the QuerySet.
@@ -378,7 +378,7 @@ class QuerySet(Generic[T]):
         ]
 
         related = sorted(list(set(list(self._select_related) + related)))
-        return self.rebuild_self(select_related=related,)
+        return self.rebuild_self(select_related=related)
 
     def select_all(self, follow: bool = False) -> "QuerySet[T]":
         """
@@ -404,7 +404,7 @@ class QuerySet(Generic[T]):
         relations = list(self.model.extract_related_names())
         if follow:
             relations = self.model._iterate_related_models()
-        return self.rebuild_self(select_related=relations,)
+        return self.rebuild_self(select_related=relations)
 
     def prefetch_related(
         self, related: Union[List, str, FieldAccessor]
@@ -434,7 +434,7 @@ class QuerySet(Generic[T]):
         ]
 
         related = list(set(list(self._prefetch_related) + related))
-        return self.rebuild_self(prefetch_related=related,)
+        return self.rebuild_self(prefetch_related=related)
 
     def fields(
         self, columns: Union[List, str, Set, Dict], _is_exclude: bool = False
@@ -490,7 +490,7 @@ class QuerySet(Generic[T]):
             is_exclude=_is_exclude,
         )
 
-        return self.rebuild_self(excludable=excludable,)
+        return self.rebuild_self(excludable=excludable)
 
     def exclude_fields(self, columns: Union[List, str, Set, Dict]) -> "QuerySet[T]":
         """
@@ -564,7 +564,7 @@ class QuerySet(Generic[T]):
         ]
 
         order_bys = self.order_bys + [x for x in orders_by if x not in self.order_bys]
-        return self.rebuild_self(order_bys=order_bys,)
+        return self.rebuild_self(order_bys=order_bys)
 
     async def values(
         self,
@@ -821,7 +821,7 @@ class QuerySet(Generic[T]):
 
         limit_count = page_size
         query_offset = (page - 1) * page_size
-        return self.rebuild_self(limit_count=limit_count, offset=query_offset,)
+        return self.rebuild_self(limit_count=limit_count, offset=query_offset)
 
     def limit(self, limit_count: int, limit_raw_sql: bool = None) -> "QuerySet[T]":
         """
@@ -838,7 +838,7 @@ class QuerySet(Generic[T]):
         :rtype: QuerySet
         """
         limit_raw_sql = self.limit_sql_raw if limit_raw_sql is None else limit_raw_sql
-        return self.rebuild_self(limit_count=limit_count, limit_raw_sql=limit_raw_sql,)
+        return self.rebuild_self(limit_count=limit_count, limit_raw_sql=limit_raw_sql)
 
     def offset(self, offset: int, limit_raw_sql: bool = None) -> "QuerySet[T]":
         """
@@ -855,7 +855,7 @@ class QuerySet(Generic[T]):
         :rtype: QuerySet
         """
         limit_raw_sql = self.limit_sql_raw if limit_raw_sql is None else limit_raw_sql
-        return self.rebuild_self(offset=offset, limit_raw_sql=limit_raw_sql,)
+        return self.rebuild_self(offset=offset, limit_raw_sql=limit_raw_sql)
 
     async def first(self, *args: Any, **kwargs: Any) -> "T":
         """
@@ -873,12 +873,16 @@ class QuerySet(Generic[T]):
 
         expr = self.build_select_expression(
             limit=1,
-            order_bys=[
-                OrderAction(
-                    order_str=f"{self.model.Meta.pkname}",
-                    model_cls=self.model_cls,  # type: ignore
-                )
-            ]
+            order_bys=(
+                [
+                    OrderAction(
+                        order_str=f"{self.model.Meta.pkname}",
+                        model_cls=self.model_cls,  # type: ignore
+                    )
+                ]
+                if not any([x.is_source_model_order for x in self.order_bys])
+                else []
+            )
             + self.order_bys,
         )
         rows = await self.database.fetch_all(expr)
@@ -909,7 +913,7 @@ class QuerySet(Generic[T]):
         except ormar.NoMatch:
             return None
 
-    async def get(self, *args: Any, **kwargs: Any) -> "T":
+    async def get(self, *args: Any, **kwargs: Any) -> "T":  # noqa: CCR001
         """
         Get's the first row from the db meeting the criteria set by kwargs.
 
@@ -931,12 +935,16 @@ class QuerySet(Generic[T]):
         if not self.filter_clauses:
             expr = self.build_select_expression(
                 limit=1,
-                order_bys=[
-                    OrderAction(
-                        order_str=f"-{self.model.Meta.pkname}",
-                        model_cls=self.model_cls,  # type: ignore
-                    )
-                ]
+                order_bys=(
+                    [
+                        OrderAction(
+                            order_str=f"-{self.model.Meta.pkname}",
+                            model_cls=self.model_cls,  # type: ignore
+                        )
+                    ]
+                    if not any([x.is_source_model_order for x in self.order_bys])
+                    else []
+                )
                 + self.order_bys,
             )
         else:
@@ -1096,6 +1104,7 @@ class QuerySet(Generic[T]):
                 )
             new_kwargs = self.model.parse_non_db_fields(new_kwargs)
             new_kwargs = self.model.substitute_models_with_pks(new_kwargs)
+            new_kwargs = self.model.reconvert_str_to_bytes(new_kwargs)
             new_kwargs = self.model.translate_columns_to_aliases(new_kwargs)
             new_kwargs = {"new_" + k: v for k, v in new_kwargs.items() if k in columns}
             ready_objects.append(new_kwargs)
